@@ -1,14 +1,14 @@
 import uuid
 import re
 
-from liquidcss.store import Storage
 from liquidcss.re_utils import Replacement
 
 
 class SelectorManager(object):
 
+
     def __init__(self):
-        self.store = Storage()
+        self.store = dict()
 
 
     def _generate_uuid(self):
@@ -19,8 +19,8 @@ class SelectorManager(object):
             return self._generate_uuid()
 
 
-    def _generate_id(self, selector_string):
-        existing = self.store.matches_existing(string = selector_string)
+    def _generate_id(self, selector_string: str) -> str:
+        existing = self.store.get(selector_string)
         if not existing:
             selector_text = self._generate_uuid()
         else:
@@ -28,7 +28,7 @@ class SelectorManager(object):
         return selector_text
 
 
-    def toggle_selector_names(self, selectors):
+    def toggle_selector_names(self, selectors: list):
         for selector in selectors:
             repl = Replacement(replacement = r'\1{}', manager = self)
             new_string = re.sub(
@@ -38,7 +38,7 @@ class SelectorManager(object):
             )
             selector.selectorText = new_string
             for matched, replaced in repl.occurrences:
-                self.store.map_[matched] = replaced[1:]
+                self.store[matched] = replaced[1:]
             
 
         
